pub struct DocText { /* private fields */ }Expand description
Lazily resolved documentation text.
Implementations
Sourceimpl DocText
impl DocText
Sourcepub fn plain(raw: EcoString) -> DocText
pub fn plain(raw: EcoString) -> DocText
Creates documentation that is already ready to display as Markdown.
Sourcepub fn official(raw: EcoString) -> DocText
pub fn official(raw: EcoString) -> DocText
Creates official Typst documentation that must be converted before display.
Sourcepub fn kind(&self) -> DocTextKind
pub fn kind(&self) -> DocTextKind
Gets the source format of this documentation text.
Sourcepub fn get_or_init(
&self,
convert_official: impl FnOnce(&EcoString) -> EcoString,
) -> &EcoString
pub fn get_or_init( &self, convert_official: impl FnOnce(&EcoString) -> EcoString, ) -> &EcoString
Gets display-ready documentation text.